<!-- Auto-generated by scripts/skill_generator.py. Do not edit manually. -->
<!-- Regenerate with: just skills -->

# Generated vs Hand-Written Files

Source of truth: `.gitattributes` marks all generated files.

## Generated files (NEVER edit directly)

These are owned by the codegen pipeline (`just generate`). Changes go through
`seeds/seed.manual.toml` or the generator scripts.

- `.claude/skills/_shared/**`
- `.gemini/skills/_shared/**`
- `skills/**`
- `src/adk_fluent/_ir_generated.py`
- `src/adk_fluent/agent.py`
- `src/adk_fluent/agent.pyi`
- `src/adk_fluent/config.py`
- `src/adk_fluent/config.pyi`
- `src/adk_fluent/executor.py`
- `src/adk_fluent/executor.pyi`
- `src/adk_fluent/planner.py`
- `src/adk_fluent/planner.pyi`
- `src/adk_fluent/plugin.py`
- `src/adk_fluent/plugin.pyi`
- `src/adk_fluent/runtime.py`
- `src/adk_fluent/runtime.pyi`
- `src/adk_fluent/service.py`
- `src/adk_fluent/service.pyi`
- `src/adk_fluent/tool.py`
- `src/adk_fluent/tool.pyi`
- `src/adk_fluent/workflow.py`
- `src/adk_fluent/workflow.pyi`
- `tests/generated/**`

## Hand-written core files (safe to edit)

- `src/adk_fluent/_base.py`
- `src/adk_fluent/_context.py`
- `src/adk_fluent/_context_providers.py`
- `src/adk_fluent/_prompt.py`
- `src/adk_fluent/_transforms.py`
- `src/adk_fluent/_routing.py`
- `src/adk_fluent/_primitives.py`
- `src/adk_fluent/_middleware.py`
- `src/adk_fluent/_tools.py`
- `src/adk_fluent/_guards.py`
- `src/adk_fluent/_artifacts.py`
- `src/adk_fluent/_eval.py`
- `src/adk_fluent/_visibility.py`
- `src/adk_fluent/patterns.py`
- `src/adk_fluent/middleware.py`
- `src/adk_fluent/decorators.py`
- `src/adk_fluent/viz.py`
- `src/adk_fluent/di.py`
- `src/adk_fluent/prelude.py`
- `src/adk_fluent/cli.py`

## Testing files

- `tests/generated/` — Auto-generated test scaffolds (NEVER edit)
- `tests/manual/` — Hand-written tests (this is where you write)
- `tests/golden/` — Snapshot tests for stability
- `examples/cookbook/` — Runnable examples (hand-written)
